import useFastAnswerStore from "./useFastAnswerStore";
import { useState } from "react";
import { deleteReply } from "../../services/fast_answer/FastAnswerService";
import toast from 'react-hot-toast';
import { Button, Modal, ModalBody, ModalContent, ModalHeader } from "@nextui-org/react";
import { useTranslation } from "@/src/hooks/useTranslation";


const IndexFastAnswer = () => {

    const { trans } = useTranslation();
    const listFastAnswer = useFastAnswerStore((state) => state.listFastAnswer);
    const setFormFastAnswer = useFastAnswerStore((state) => state.setFormFastAnswer);
    const getReplies = useFastAnswerStore((state) => state.getReplies);
    const [loading, setLoading] = useState(false);
    const [deleteAnswer, setDeleteAnswer] = useState({
        id: "",
        id_chatbot: "",
        rapido: "",
        mensaje_largo: "",
    });
    const [openModal, setOpenModal] = useState(false);

    const handleEditFastAnswerInput = (e: any, item: any) => {
        setFormFastAnswer(item);
        useFastAnswerStore.setState({ optionsView: 'update_answer' })
    }

    const handleDeleteFastAnswerInput = (e: any, item: any) => {
        setDeleteAnswer(item);
        setOpenModal(true);
    }

    const handleDeleteAnswer = () => {
        setLoading(true);
        deleteReply(deleteAnswer.id_chatbot, deleteAnswer.id).then((res) => {
            if (res.status == 500) {
                toast.error(`${trans('modal_conversations_answer_fast_alert_delete_error_title')} ${deleteAnswer.rapido}`);
                setOpenModal(false);
            } else {
                toast.success(`${trans('modal_conversations_answer_fast_alert_success_title')} ${deleteAnswer.rapido}`);
                setOpenModal(false);
                getReplies(deleteAnswer.id_chatbot);
            }
            setLoading(false);
        })
    }

    return (
        <div className="custom-scroll" style={{ maxHeight: '500px', overflow: 'auto' }}>
            <table className="w-full text-sm text-left rtl:text-right text-gray-700 dark:text-gray-400">
                <thead className="text-sm text-gray-700 uppercase bg-gray-50 dark:bg-gray-700 dark:text-gray-400">
                    <tr>
                        <th>Id</th>
                        <th>{trans('modal_conversations_answer_fast_table_title_one')}</th>
                        <th>{trans('modal_conversations_answer_fast_table_title_two')}</th>
                    </tr>
                </thead>
                <tbody>
                    {listFastAnswer.filter((item: any) => item.supervisor == 0).map((item: any, index) => (

                        <tr className="bg-white border-b dark:bg-gray-800 dark:border-gray-700" key={index}>
                            <td>{index + 1}</td>
                            <td>{item.rapido}</td>
                            <td className="flex gap-2 justify-end p-1 items-center">
                                <button
                                    onClick={(e) => handleEditFastAnswerInput(e, { id: item.id, title: item.rapido, description: item.mensaje_largo })}
                                    className="text-lg text-default-600 cursor-pointer active:opacity-50"
                                    title={trans('modal_conversations_answer_fast_table_toltip_button_edit')}
                                >
                                    <i className="fa fa-edit"></i>
                                </button>
                                <button
                                    title={trans('modal_conversations_answer_fast_table_toltip_button_delete')}
                                    className="text-lg text-danger cursor-pointer active:opacity-50"
                                    onClick={(e) => handleDeleteFastAnswerInput(e, item)}
                                >
                                    <i className="fa fa-trash"></i>
                                </button>
                            </td>
                        </tr>
                    ))}
                </tbody>
            </table>
            <Modal
                isOpen={openModal}
                onOpenChange={() => setOpenModal(!openModal)}
            >
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>{trans('modal_conversations_answer_fast_table_toltip_button_delete')}</ModalHeader>
                            <ModalBody>
                                <div className="p-2 flex flex-col justify-center items-center gap-2">
                                    <div className="col-md-12 text-center m-3">
                                        <h3>{trans('modal_conversations_answer_fast_confirm_delete_success_title')} {deleteAnswer.rapido} ?</h3>
                                    </div>
                                    <div className="col-md-12 text-center">
                                        <Button size="sm" color="danger" isLoading={loading} onClick={() => handleDeleteAnswer()}>
                                            {loading ? trans('modal_conversations_answer_fast_confirm_loading_title') : trans('modal_conversations_answer_fast_table_toltip_button_delete')}
                                        </Button>
                                    </div>
                                </div>
                            </ModalBody>
                        </>
                    )}
                </ModalContent>
            </Modal>
        </div>
    )
}

export default IndexFastAnswer